@@ -24,7 +24,7 @@ Note:
     equality comparisons (`==`) for stubbing and verification.
 """
 from re import compile as compile_re
-from typing import cast, Any, List, Mapping, Optional, Pattern, Type
+from typing import cast, Any, List, Mapping, Optional, Pattern, Type, TypeVar
 
 
 __all__ = [
@@ -74,8 +74,10 @@ class _IsA:
 
     def __eq__(self, target: object) -> bool:
         """Return true if target is the correct type and matches attributes."""
-        matches_type = type(target) == self._match_type
-        matches_attrs = target == HasAttributes(self._attributes or {})
+        matches_type = isinstance(target, self._match_type)
+        matches_attrs = (
+            target == HasAttributes(self._attributes) if self._attributes else True
+        )
 
         return matches_type and matches_attrs
 
@@ -255,10 +257,10 @@ def StringMatching(match: str) -> str:
 
 
 class _ErrorMatching:
-    _error_type: Type[Exception]
+    _error_type: Type[BaseException]
     _string_matcher: Optional[_StringMatching]
 
-    def __init__(self, error: Type[Exception], match: Optional[str] = None) -> None:
+    def __init__(self, error: Type[BaseException], match: Optional[str] = None) -> None:
         """Initialize with the Exception type and optional message matcher."""
         self._error_type = error
         self._string_matcher = _StringMatching(match) if match is not None else None
@@ -281,7 +283,10 @@ class _ErrorMatching:
         )
 
 
-def ErrorMatching(error: Type[Exception], match: Optional[str] = None) -> Exception:
+ErrorT = TypeVar("ErrorT", bound=BaseException)
+
+
+def ErrorMatching(error: Type[ErrorT], match: Optional[str] = None) -> ErrorT:
     """Match any error matching an Exception type and optional message matcher.
 
     Arguments:
@@ -294,7 +299,7 @@ def ErrorMatching(error: Type[Exception], match: Optional[str] = None) -> Except
         assert ValueError("oh no!") == ErrorMatching(ValueError, match="no")
         ```
     """
-    return cast(Exception, _ErrorMatching(error, match))
+    return cast(ErrorT, _ErrorMatching(error, match))
 
 
 class _Captor:
